/*
 * Copyright 2020-2021 Google LLC
 * Copyright 2020-2021 EPAM Systems, Inc
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.opengroup.osdu.partition.provider.gcp.osm.config.mapper;

import com.google.cloud.datastore.Key;
import com.google.common.collect.ImmutableList;
import com.google.common.collect.ImmutableMap;
import org.opengroup.osdu.core.gcp.osm.persistence.IdentityTranslator;
import org.opengroup.osdu.core.gcp.osm.translate.Instrumentation;
import org.opengroup.osdu.core.gcp.osm.translate.TypeMapper;
import org.opengroup.osdu.partition.provider.gcp.model.PartitionPropertyEntity;
import org.springframework.boot.autoconfigure.condition.ConditionalOnProperty;
import org.springframework.context.annotation.Scope;
import org.springframework.stereotype.Component;

import java.util.Collections;
import java.util.HashMap;

import static org.springframework.beans.factory.config.BeanDefinition.SCOPE_SINGLETON;

@Component
@Scope(SCOPE_SINGLETON)
@ConditionalOnProperty(name = "osmDriver")
public class TypeMapperImpl extends TypeMapper {
    public TypeMapperImpl(){
        super(ImmutableList.of(
                new Instrumentation<>(PartitionPropertyEntity.class,
                        new HashMap<String, String>() {{
                            put("partitionId", "partition_id");
                        }},
                        ImmutableMap.of(),
                        new IdentityTranslator<>(
                                PartitionPropertyEntity::getId,
                                (p, o) -> p.setId(((Key)o).getName())
                        ),
                        Collections.singletonList("id")
                ))
        );
    }
}
